==> deltaxmobilesdk-0.0.4.tar.gz: lib/deltaxmobilesdk.dart <==
import 'dart:async';

import 'package:flutter/services.dart';

class Deltaxmobilesdk {
  static const MethodChannel _channel = MethodChannel('deltaxmobilesdk');

  static Future<String?> get platformVersion async {
    final String? version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  static void init(String? xb) async {
    Map params = {
      "xb": xb,
    };
    await _channel.invokeMethod('initTrackerInstance', params);
  }

  static void setCustomerId(String id, {String? xb = ""}) async {
    Map params = {"xb": xb, "customerId": id};
    await _channel.invokeMethod('setCustomerId', params);
  }

  static void setCustomerEmail(String email,
      {String? xb = "", bool doNotEncode = false}) async {
    Map params = {
      "xb": xb,
      "email": email,
      "doNotEncode": doNotEncode.toString()
    };
    await _channel.invokeMethod('setCustomerEmail', params);
  }

  static void setCustomerPhoneNumber(String phoneNumber,
      {String? xb = "", bool doNotEncode = false}) async {
    Map params = {
      "xb": xb,
      "phoneNumber": phoneNumber,
      "doNotEncode": doNotEncode.toString()
    };
    await _channel.invokeMethod('setCustomerPhoneNumber', params);
  }

  static void registerDxLinkDomain(String dxLinkDomain,
      {String? xb = ""}) async {
    Map params = {"xb": xb, "dxLinkDomain": dxLinkDomain};
    await _channel.invokeMethod('registerDxLinkDomain', params);
  }

  static void trackEvent({Map<String, String>? values, String? xb = ""}) async {
    Map params = {"xb": xb, "values": values};
    await _channel.invokeMethod('trackEvent', params);
  }

  static void trackClick(Uri uri, {String? xb = ""}) async {
    Map params = {"xb": xb, "uri": uri.toString()};
    await _channel.invokeMethod('trackClicks', params);
  }

  static void disableTracking() async {
    await _channel.invokeMethod('disableTracking');
  }

  static void enableTracking() async {
    await _channel.invokeMethod('enableTracking');
  }
}

==> deltaxmobilesdk-0.0.6.tar.gz: lib/deltaxmobilesdk.dart <==
import 'dart:async';

import 'package:flutter/services.dart';

class Deltaxmobilesdk {
  static const MethodChannel _channel = MethodChannel('deltaxmobilesdk');

  static Future<String?> get platformVersion async {
    final String? version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  static void init(String? xb) async {
    Map params = {
      "xb": xb,
    };
    await _channel.invokeMethod('initTrackerInstance', params);
  }

  static void setCustomerId(String id, {String? xb = ""}) async {
    Map params = {"xb": xb, "customerId": id};
    await _channel.invokeMethod('setCustomerId', params);
  }

  static void setCustomerEmail(String email,
      {String? xb = "", bool doNotEncode = false}) async {
    Map params = {
      "xb": xb,
      "email": email,
      "doNotEncode": doNotEncode.toString()
    };
    await _channel.invokeMethod('setCustomerEmail', params);
  }

  static void setCustomerPhoneNumber(String phoneNumber,
      {String? xb = "", bool doNotEncode = false}) async {
    Map params = {
      "xb": xb,
      "phoneNumber": phoneNumber,
      "doNotEncode": doNotEncode.toString()
    };
    await _channel.invokeMethod('setCustomerPhoneNumber', params);
  }

  static void registerDxLinkDomain(String dxLinkDomain,
      {String? xb = ""}) async {
    Map params = {"xb": xb, "dxLinkDomain": dxLinkDomain};
    await _channel.invokeMethod('registerDxLinkDomain', params);
  }

  static void trackEvent({Map<String, String>? values, String? xb = ""}) async {
    Map params = {"xb": xb, "values": values};
    await _channel.invokeMethod('trackEvent', params);
  }

  static void trackClick(Uri uri, {String? xb = ""}) async {
    Map params = {"xb": xb, "uri": uri.toString()};
    await _channel.invokeMethod('trackClick', params);
  }

  static void disableTracking() async {
    await _channel.invokeMethod('disableTracking');
  }

  static void enableTracking() async {
    await _channel.invokeMethod('enableTracking');
  }
}
